#include <cstdlib>
#include <cstring>
#include <iostream>

#include "storybook.h"

void usage(const char* bin) {
  fprintf(stderr, "Usage: %s <storyfile>", bin);
  exit(1);
}

int main(int argc, const char *argv[]) {
  if (argc != 2) {
    usage(argv[0]);
  }

  FILE *fin = fopen(argv[1], "r");
  if (!fin) {
    fprintf(stderr, "Error: could not read %s", argv[1]);
    return 2;
  }
  Storybook sb(fin);
  fclose(fin);

  sb.Find("START");
  sb.Play();

  while (!sb.IsEnded) {
    sb.Play();
  }

  return 0;
}


Storybook::Storybook(FILE* fin) {
  pages = CyoaParse(fin);
}


void Storybook::Find(const char* id) {
  for (Page* page : pages) {
    if (strcmp(page->id, id) == 0) {
      current = page;
      return;
    }
  }
  // If not found
  current = NULL;
}

void print_choice(Choice* c) {
  printf("%d) %s", c->option, c->flavor);
  if (c->statcheck) {
    //TODO
  }
  printf("\n");
}

void Storybook::Play() {
  printf(current->body);

  switch (current->footer.type) {
  case FooterType::End:
    printf("The End.");
    IsEnded = true;
    break;
  case FooterType::Goto:
    Find(current->footer.link);
    printf("Press ENTER to continue...");
    std::cin.get();
    break;
  case FooterType::Choices:
    for (auto c : *current->footer.choices) {
      print_choice(c.second);
    }
  default:
    IsEnded = true; // TODO
  }
}
